package com.kms;

import com.j256.ormlite.dao.Dao;
import com.j256.ormlite.dao.DaoManager;
import com.j256.ormlite.jdbc.JdbcConnectionSource;
import com.j256.ormlite.support.ConnectionSource;
import com.j256.ormlite.table.TableUtils;
import com.kms.crosscut.LoggingHelper;
import com.kms.model.Log;
import com.kms.model.Payment;
import com.kms.service.PaymentHistoryService;
import com.kms.service.PaymentService;
import com.kms.task.PaymentCompleterTask;
import com.kms.task.PdfCleanerTask;

import javax.xml.ws.Endpoint;
import java.sql.SQLException;
import java.util.Timer;

public class App {

    private static final String MYSQL_HOSTNAME =
            System.getenv().getOrDefault("MYSQL_HOSTNAME", "localhost");

    public static void main( String[] args ) {
        try {
            final String databaseUrl = "jdbc:mysql://"+MYSQL_HOSTNAME+":3306/db?user=user&password=password";
            final ConnectionSource connectionSource = new JdbcConnectionSource(databaseUrl);
            final Dao<Payment,Integer> paymentDao = DaoManager.createDao(connectionSource, Payment.class);
            final Dao<Log,Integer> logDao = DaoManager.createDao(connectionSource, Log.class);
            LoggingHelper.init(logDao);

            TableUtils.createTableIfNotExists(connectionSource, Payment.class);
            TableUtils.createTableIfNotExists(connectionSource, Log.class);

            final Timer time = new Timer();
            PaymentCompleterTask task = new PaymentCompleterTask(paymentDao);
            time.schedule(task, 0, 25000);

            final Timer timePdf = new Timer();
            PdfCleanerTask pdfCleanerTask = new PdfCleanerTask();
            timePdf.schedule(pdfCleanerTask, 0, 25000);

            Endpoint.publish("http://0.0.0.0:8080/paymentservice", new PaymentService(paymentDao));
            Endpoint.publish("http://0.0.0.0:8080/paymenthistory", new PaymentHistoryService(paymentDao));
        } catch (SQLException e) {
            System.out.println("error: " + e.getMessage());
        }

    }
}
