package com.kms.service.helper;

import redis.clients.jedis.Jedis;
import redis.clients.jedis.JedisPool;

public class PaymentHistoryCacheHelper {

    private static final String REDIS_HOSTNAME =
            System.getenv().getOrDefault("REDIS_HOSTNAME", "localhost");
    private static final JedisPool jedisPool = new JedisPool(REDIS_HOSTNAME, 6379);

    /**
     *
     * @param initiatorId initiator id for cache key
     * @return cache key, empty if cache is not available
     */
    public static String checkForHistoryCacheAvailability(String initiatorId) {
        String cacheKey = formHistoryCacheKey(initiatorId);
        try (Jedis jedis = jedisPool.getResource()) {
            boolean keyExists = jedis.exists(cacheKey);
            if (!keyExists)
                return "";

            long ttlSeconds = jedis.ttl(cacheKey);
            if (ttlSeconds < 3) {
                jedis.expire(cacheKey, 3);
            }
            return cacheKey;
        }
    }

    public static String formHistoryCacheKey(String initiatorId) {
        return "payment-history:"+initiatorId;
    }

}
