package com.kms.util;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.xhtmlrenderer.layout.SharedContext;
import org.xhtmlrenderer.pdf.ITextRenderer;

import java.io.File;
import java.io.IOException;
import java.io.OutputStream;
import java.nio.file.Files;

public class PdfUtil {

    private static final String PDF_FILE_LOCATION;

    static {
        String pdfFileLocation = System.getenv("PDF_FILE_LOCATION");

        if (!pdfFileLocation.endsWith("/")) {
            pdfFileLocation += "/";
        }

        PDF_FILE_LOCATION = pdfFileLocation;
    }

    public static void writePdfToFile(String html, String filename) {
        final File file = new File(PDF_FILE_LOCATION+filename);
        System.out.println("WRITING PDF TO: " + PDF_FILE_LOCATION+filename);
        Document document = Jsoup.parse(html, "UTF-8");
        document.outputSettings().syntax(Document.OutputSettings.Syntax.xml);

        try (OutputStream outputStream = Files.newOutputStream(file.toPath())) {
            ITextRenderer renderer = new ITextRenderer();
            SharedContext sharedContext = renderer.getSharedContext();
            sharedContext.setPrint(true);
            renderer.setDocumentFromString(document.html());
            renderer.layout();

            renderer.createPDF(outputStream);
        } catch (IOException ignored) {
        }
    }

    public static String getPdfFolder() {
        return PDF_FILE_LOCATION;
    }

    public static boolean checkPdfExists(String filename) {
        final File file = new File(PDF_FILE_LOCATION+filename);
        return file.isFile() && file.exists();
    }

}
